package com.ruoyi.syzy.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.syzy.mapper.BWwwNewsMapper;
import com.ruoyi.syzy.domain.BWwwNews;
import com.ruoyi.syzy.service.IBWwwNewsService;

/**
 * 高考资讯Service业务层处理
 * 
 * @author mingxue
 * @date 2021-07-26
 */
@Service
public class BWwwNewsServiceImpl implements IBWwwNewsService {
    @Autowired
    private BWwwNewsMapper bWwwNewsMapper;

    /**
     * 查询高考资讯
     * 
     * @param id 高考资讯ID
     * @return 高考资讯
     */
    @Override
    public BWwwNews selectBWwwNewsById(Long id) {
        return bWwwNewsMapper.selectBWwwNewsById(id);
    }

    /**
     * 查询高考资讯列表
     * 
     * @param bWwwNews 高考资讯
     * @return 高考资讯
     */
    @Override
    public List<BWwwNews> selectBWwwNewsList(BWwwNews bWwwNews) {
        return bWwwNewsMapper.selectBWwwNewsList(bWwwNews);
    }

    /**
     * 新增高考资讯
     * 
     * @param bWwwNews 高考资讯
     * @return 结果
     */
    @Override
    public int insertBWwwNews(BWwwNews bWwwNews) {
        return bWwwNewsMapper.insertBWwwNews(bWwwNews);
    }

    /**
     * 修改高考资讯
     * 
     * @param bWwwNews 高考资讯
     * @return 结果
     */
    @Override
    public int updateBWwwNews(BWwwNews bWwwNews) {
        return bWwwNewsMapper.updateBWwwNews(bWwwNews);
    }

    /**
     * 批量删除高考资讯
     * 
     * @param ids 需要删除的高考资讯ID
     * @return 结果
     */
    @Override
    public int deleteBWwwNewsByIds(Long[] ids) {
        return bWwwNewsMapper.deleteBWwwNewsByIds(ids);
    }

    /**
     * 删除高考资讯信息
     * 
     * @param id 高考资讯ID
     * @return 结果
     */
    @Override
    public int deleteBWwwNewsById(Long id) {
        return bWwwNewsMapper.deleteBWwwNewsById(id);
    }
}
